OC.L10N.register(
    "text",
    {
    "New text file" : "Ný textaskrá",
    "Create new text file" : "Búa til nýja textaskrá",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu.",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "No file uploaded or file size exceeds maximum of %s" : "Engin innsend skrá eða að skráarstærð fór fram úr hámarksstæðinni %s",
    "Nextcloud Text" : "Nextcloud Texti",
    "text document" : "textaskjal",
    "{user} has mentioned you in the text document {node}" : "{user} minntist á þig í textaskjalinu {node}",
    "Readme" : "Readme upplýsingaskrá",
    "Text" : "Texti",
    "📝 Collaborative document editing" : "📝 Samstarfsforrit til vinnslu skjala",
    "Nextcloud Assistant" : "Nextcloud Aðstoð",
    "Translate" : "Þýða",
    "Insert result" : "Setja inn niðurstöðu",
    "Show result" : "Birta niðurstöðu",
    "Delete task" : "Eyða verki",
    "Could not copy result to clipboard" : "Gat ekki afritað niðurstöðu á klippispjald",
    "Use current version" : "Nota fyrirliggjandi útgáfu",
    "Use the saved version" : "Nota vistuðu útgáfuna",
    "Failed to load file" : "Gat ekki lesið skrána",
    "Document idle for {timeout} minutes, click to continue editing" : "Skjal aðgerðalaust í {timeout} mínútur, smelltu til að halda áfram með breytingar",
    "Reconnect" : "Endurtengjast",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Skjalinu hefur verið breytt utan ritilsins. Ekki var hægt að framkvæma breytingarnar.",
    "File could not be loaded. Please check your internet connection." : "Ekki var hægt að hlaða inn skránni. Athugaðu nettenginguna þína.",
    "This file is opened read-only as it is currently locked by {user}." : "Þessi skrá er ritvarin þar sem henni er læst af {user}.",
    "Close outline view" : "Loka efnisskipulagssýn",
    "Outline" : "Efnisskipan",
    "Enter your name so other people can see who is editing" : "Settu inn nafnið þitt svo aðrir notendur geti séð hver sé að breyta hverju",
    "Edit guest name" : "Breyta nafni gests",
    "Guest" : "Gestur",
    "Save guest name" : "Vista nafn gests",
    "Insert an attachment" : "Setja inn viðhengi",
    "guest" : "gestanotandi",
    "Show author colors" : "Sýna liti höfunda",
    "Author colors are only shown until everyone has closed the document." : "Litir höfunda eru aðeins sýndir þar til allir hafa lokað skjalinu.",
    "Active people" : "Virkt fólk",
    "Save document" : "Vista skjal",
    "Last saved" : "Síðast vistað",
    "Offline" : "Ótengt neti",
    "Offline, changes will be saved when online" : "Án nettengingar verður vistað næst þegar tenging kemst á",
    "Saving …" : "Vista …",
    "Saved" : "Vistað",
    "Last saved {lastSave}" : "Síðast vistað {lastSave}",
    "Unsaved changes" : "Óvistaðar breytingar",
    "Formatting help" : "Hjálp við að sníða",
    "Speed up your writing with simple shortcuts." : "Flýttu fyrir vinnu þinni við skriftir með einföldum flýtilyklum.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Skrifaðu einfaldlega Markdown-málskipan eða flýtilykla sem birtast hér fyrir neðan.",
    "Just type the Markdown syntax from below." : "Skrifaðu einfaldlega Markdown-málskipan sem birtist hér fyrir neðan.",
    "Style" : "Stíll",
    "Syntax" : "Málskipun",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "New paragraph" : "Ný málsgrein",
    "Enter" : "Enter",
    "Hard line break" : "Hörð línuskil",
    "followed by" : "fylgt af",
    "Backspace" : "Baklykill (backspace)",
    "Shift" : "Shift",
    "Bold" : "Feitletrað",
    "Bold text" : "Feitletraður texti",
    "Ctrl" : "Ctrl",
    "Italic" : "Skáletrað",
    "Italicized text" : "Skáletraður texti",
    "Strikethrough" : "Gegnumstrikað",
    "Mistaken text" : "Útstrikaður texti",
    "Underline" : "Undirstrikað",
    "Underlined text" : "Undirstrikaður texti",
    "Heading 1" : "Fyrirsögn 1",
    "Heading level 1" : "Fyrirsögn stig 1",
    "Heading 6" : "Fyrirsögn 6",
    "Heading level 6" : "Fyrirsögn stig 6",
    "Unordered list" : "Óraðaður listi",
    "An item" : "Atriði",
    "Ordered list" : "Raðaður listi",
    "First item" : "Fyrsta atriði",
    "Checklist" : "Gátlisti",
    "To-Do item" : "Atriði verkefnalista",
    "Blockquote" : "Tilvitnun",
    "Quoted text" : "Tilvitnaður texti",
    "Code block" : "Kóðablokk",
    "Some code" : "Einhver kóði",
    "Remove link" : "Fjarlægja tengil",
    "Cancel" : "Hætta við",
    "URL" : "Slóð",
    "Cannot copy, please copy the link manually" : "Mistókst að afrita, afritaðu tengilinn handvirkt",
    "Copy link to clipboard" : "Afrita tengil á klippispjald",
    "Upload from computer" : "Senda inn úr tölvunni",
    "Insert from Files" : "Setja inn úr skrám",
    "Link to file or folder" : "Tengill á skrá eða möppu",
    "Link to website" : "Tengill á vefsvæði",
    "Update link" : "Uppfæra tengil",
    "Open the Smart Picker" : "Opna snjallveljarann",
    "Select file or folder to link to" : "Veldu skrá eða möppu til að tengja í",
    "_%n word_::_%n words_" : ["%n orð","%n orð"],
    "_%n char_::_%n chars_" : ["%n stafur","%n stafir"],
    "Editor actions" : "Aðgerðir ritils",
    "Formatting menu bar" : "Valmyndastika fyrir snið",
    "Remaining actions" : "Eftirliggjandi aðgerðir",
    "To translate individual parts of the text, select it before using the translate function." : "Til að þýða einstaka hluta textans, skaltu velja þá áður en þú velur þýðingaaðgerðina.",
    "Translate from" : "Þýða úr",
    "Select language" : "Veldu tungumál",
    "to" : "til",
    "Replace" : "Skipta út",
    "Insert" : "Setja inn",
    "Detect language" : "Greina tungumál",
    "Translate from {language}" : "Þýða úr {language}",
    "Translate to {language}" : "Þýða yfir á {language}",
    "Translation failed" : "Þýðing mistókst",
    "No emoji found" : "Ekkert tjáningartákn fannst",
    "No command found" : "Engin skipun fannst",
    "No user found" : "Enginn notandi fannst",
    "No suggestion found" : "Engin tillaga fannst",
    "Code block options" : "Valkostir kóðablokkar",
    "Code block language" : "Tungumál kóðablokkar",
    "e.g. php, javascript, json…" : "t.d. php, javascript, json…",
    "Source code" : "Upprunakóði",
    "Diagram" : "Skýringamynd",
    "Both" : "Bæði",
    "Mermaid documentation" : "Hjálparskjöl Mermaid",
    "Link to this section" : "Tengja í þennan hluta",
    "Delete this attachment" : "Eyða þessu viðhengi",
    "Delete this image" : "Eyða þessari mynd",
    "Failed to load" : "Mistókst að hlaða inn",
    "Add row before" : "Bæta við röð á undan",
    "Add row after" : "Bæta við röð á eftir",
    "Delete this row" : "Eyða þessari röð",
    "Left align column" : "Jafna dálk til vinstri",
    "Center align column" : "Jafna dálk á miðju",
    "Right align column" : "Jafna dálk til hægri",
    "Add column before" : "Bæta við dálki á undan",
    "Add column after" : "Bæta við dálki á eftir",
    "Delete this column" : "Eyða þessum dálki",
    "Delete this table" : "Eyða þessari töflu",
    "Show folder description" : "Birta lýsingu möppunnar",
    "Hide outline" : "Fela útlínu",
    "Show outline" : "Birta útlínu",
    "Undo" : "Afturkalla",
    "Redo" : "Endurtaka",
    "Headings" : "Fyrirsagnir",
    "Heading 2" : "Fyrirsögn 2",
    "Heading 3" : "Fyrirsögn 3",
    "Heading 4" : "Fyrirsögn 4",
    "Heading 5" : "Fyrirsögn 5",
    "To-Do list" : "Verkþáttalisti",
    "Insert link" : "Setja inn tengil",
    "Callouts" : "Talblöðrur",
    "Info" : "Upplýsingar",
    "Success" : "Tókst",
    "Warning" : "Aðvörun",
    "Danger" : "Hættulegt",
    "Table" : "Tafla",
    "Insert emoji" : "Setja inn tjáningartákn",
    "Insert attachment" : "Setja inn viðhengi",
    "Command" : "Skipun",
    "Control" : "Stjórnun",
    "Option" : "Valkostur",
    "Formatting" : "Sniðmótun",
    "Smart picker" : "Snjall-veljari",
    "Add notes, lists or links …" : "Bættu við minnispunktum, listum eða tenglum …",
    "Edit" : "Breyta",
    "Add description" : "Bæta við lýsingu",
    "\"{name}\" already exist!" : "\"{name}\" er þegar til staðar!",
    "Created \"{name}\"" : "Bjó til \"{name}\"",
    "Source language" : "Upprunatungumál",
    "Target language" : "Marktungumál:",
    "Unsupported image type" : "Óstudd gerð myndar",
    "Show rich workspaces" : "Birta vinnusvæði með sniðmöguleikum",
    "e.g. php, javascript, json, ..." : "t.d. php, javascript, json, ..."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
